# Create your views here.
from django.shortcuts import render_to_response
from django.template.context import RequestContext
from django.http import HttpResponseRedirect

from user_profile.forms import ProfileForm
from user_profile.models import Profile
from django.contrib.auth.decorators import login_required

@login_required
def change(request):
    profile, create = Profile.objects.get_or_create(user=request.user)
    
    #profile=Profile.objects.filter(user=request.user).get()
    if request.method== "POST":
        form=ProfileForm(request.POST, instance=profile)
        if form.is_valid():
            profile= form.save(commit=False)
            profile.save()
        
            return HttpResponseRedirect('/pin/user/%d' % request.user.id)
    else:
        form = ProfileForm(instance=profile)
    return render_to_response('change.html',{'form':form},context_instance=RequestContext(request))



#coding: utf-8
from django.db import models
from django.contrib.auth.models import User

class Profile(models.Model):
    name=models.CharField(max_length=250,verbose_name='نام')
    location=models.CharField(max_length=250, verbose_name='موقعیت', blank=True)
    website=models.URLField(verbose_name='وب سایت', blank=True)
    bio=models.TextField(verbose_name='توضیحات', blank=True)
    user=models.ForeignKey(User)



from setuptools import find_packages

from distutils.core import setup

version = '1.0.0'

setup(
    name = "django-user-profile",
    version = "1.0.0",
    packages = ['user_profile'],
    author = "vahid chakoshy",
    author_email = "vchakoshy@gmail.com",
    description = "user profile for pinterest apllication like in Django",
    url = "http://www.wisgoon.com/",
    py_modules = ["user_rofile"],
    #package_dir = {},
    package_dir = {'user_rofile': 'user_rofile'},
    include_package_data = True,
    zip_safe=False,
)
